@@ -1,3 +1,6 @@
+from py42.sdk.queries.query_filter import FilterGroup
+
+
 class BaseQuery(object):
     def __init__(self, *args, **kwargs):
         self._filter_group_list = list(args)
@@ -9,6 +12,13 @@ class BaseQuery(object):
         self.page_number = None
         self.sort_key = None
 
+    @classmethod
+    def from_dict(cls, _dict, group_clause=u"AND"):
+        filter_groups = [
+            FilterGroup.from_dict(item, item[u"filterClause"]) for item in _dict[u"groups"]
+        ]
+        return cls(*filter_groups, group_clause=group_clause)
+
     @classmethod
     def any(cls, *args):
         return cls(*args, group_clause=u"OR")
